[−][src]Enum unicode_types::chess_symbols::ChessSymbols
An enum to represent all characters in the ChessSymbols block.
Variants
NeutralChessKing\u{1fa00}: '🨀'
NeutralChessQueen\u{1fa01}: '🨁'
NeutralChessRook\u{1fa02}: '🨂'
NeutralChessBishop\u{1fa03}: '🨃'
NeutralChessKnight\u{1fa04}: '🨄'
NeutralChessPawn\u{1fa05}: '🨅'
WhiteChessKnightRotatedFortyDashFiveDegrees\u{1fa06}: '🨆'
BlackChessKnightRotatedFortyDashFiveDegrees\u{1fa07}: '🨇'
NeutralChessKnightRotatedFortyDashFiveDegrees\u{1fa08}: '🨈'
WhiteChessKingRotatedNinetyDegrees\u{1fa09}: '🨉'
WhiteChessQueenRotatedNinetyDegrees\u{1fa0a}: '🨊'
WhiteChessRookRotatedNinetyDegrees\u{1fa0b}: '🨋'
WhiteChessBishopRotatedNinetyDegrees\u{1fa0c}: '🨌'
WhiteChessKnightRotatedNinetyDegrees\u{1fa0d}: '🨍'
WhiteChessPawnRotatedNinetyDegrees\u{1fa0e}: '🨎'
BlackChessKingRotatedNinetyDegrees\u{1fa0f}: '🨏'
BlackChessQueenRotatedNinetyDegrees\u{1fa10}: '🨐'
BlackChessRookRotatedNinetyDegrees\u{1fa11}: '🨑'
BlackChessBishopRotatedNinetyDegrees\u{1fa12}: '🨒'
BlackChessKnightRotatedNinetyDegrees\u{1fa13}: '🨓'
BlackChessPawnRotatedNinetyDegrees\u{1fa14}: '🨔'
NeutralChessKingRotatedNinetyDegrees\u{1fa15}: '🨕'
NeutralChessQueenRotatedNinetyDegrees\u{1fa16}: '🨖'
NeutralChessRookRotatedNinetyDegrees\u{1fa17}: '🨗'
NeutralChessBishopRotatedNinetyDegrees\u{1fa18}: '🨘'
NeutralChessKnightRotatedNinetyDegrees\u{1fa19}: '🨙'
NeutralChessPawnRotatedNinetyDegrees\u{1fa1a}: '🨚'
WhiteChessKnightRotatedOneHundredThirtyDashFiveDegrees\u{1fa1b}: '🨛'
BlackChessKnightRotatedOneHundredThirtyDashFiveDegrees\u{1fa1c}: '🨜'
NeutralChessKnightRotatedOneHundredThirtyDashFiveDegrees\u{1fa1d}: '🨝'
WhiteChessTurnedKing\u{1fa1e}: '🨞'
WhiteChessTurnedQueen\u{1fa1f}: '🨟'
WhiteChessTurnedRook\u{1fa20}: '🨠'
WhiteChessTurnedBishop\u{1fa21}: '🨡'
WhiteChessTurnedKnight\u{1fa22}: '🨢'
WhiteChessTurnedPawn\u{1fa23}: '🨣'
BlackChessTurnedKing\u{1fa24}: '🨤'
BlackChessTurnedQueen\u{1fa25}: '🨥'
BlackChessTurnedRook\u{1fa26}: '🨦'
BlackChessTurnedBishop\u{1fa27}: '🨧'
BlackChessTurnedKnight\u{1fa28}: '🨨'
BlackChessTurnedPawn\u{1fa29}: '🨩'
NeutralChessTurnedKing\u{1fa2a}: '🨪'
NeutralChessTurnedQueen\u{1fa2b}: '🨫'
NeutralChessTurnedRook\u{1fa2c}: '🨬'
NeutralChessTurnedBishop\u{1fa2d}: '🨭'
NeutralChessTurnedKnight\u{1fa2e}: '🨮'
NeutralChessTurnedPawn\u{1fa2f}: '🨯'
WhiteChessKnightRotatedTwoHundredTwentyDashFiveDegrees\u{1fa30}: '🨰'
BlackChessKnightRotatedTwoHundredTwentyDashFiveDegrees\u{1fa31}: '🨱'
NeutralChessKnightRotatedTwoHundredTwentyDashFiveDegrees\u{1fa32}: '🨲'
WhiteChessKingRotatedTwoHundredSeventyDegrees\u{1fa33}: '🨳'
WhiteChessQueenRotatedTwoHundredSeventyDegrees\u{1fa34}: '🨴'
WhiteChessRookRotatedTwoHundredSeventyDegrees\u{1fa35}: '🨵'
WhiteChessBishopRotatedTwoHundredSeventyDegrees\u{1fa36}: '🨶'
WhiteChessKnightRotatedTwoHundredSeventyDegrees\u{1fa37}: '🨷'
WhiteChessPawnRotatedTwoHundredSeventyDegrees\u{1fa38}: '🨸'
BlackChessKingRotatedTwoHundredSeventyDegrees\u{1fa39}: '🨹'
BlackChessQueenRotatedTwoHundredSeventyDegrees\u{1fa3a}: '🨺'
BlackChessRookRotatedTwoHundredSeventyDegrees\u{1fa3b}: '🨻'
BlackChessBishopRotatedTwoHundredSeventyDegrees\u{1fa3c}: '🨼'
BlackChessKnightRotatedTwoHundredSeventyDegrees\u{1fa3d}: '🨽'
BlackChessPawnRotatedTwoHundredSeventyDegrees\u{1fa3e}: '🨾'
NeutralChessKingRotatedTwoHundredSeventyDegrees\u{1fa3f}: '🨿'
NeutralChessQueenRotatedTwoHundredSeventyDegrees\u{1fa40}: '🩀'
NeutralChessRookRotatedTwoHundredSeventyDegrees\u{1fa41}: '🩁'
NeutralChessBishopRotatedTwoHundredSeventyDegrees\u{1fa42}: '🩂'
NeutralChessKnightRotatedTwoHundredSeventyDegrees\u{1fa43}: '🩃'
NeutralChessPawnRotatedTwoHundredSeventyDegrees\u{1fa44}: '🩄'
WhiteChessKnightRotatedThreeHundredFifteenDegrees\u{1fa45}: '🩅'
BlackChessKnightRotatedThreeHundredFifteenDegrees\u{1fa46}: '🩆'
NeutralChessKnightRotatedThreeHundredFifteenDegrees\u{1fa47}: '🩇'
WhiteChessEquihopper\u{1fa48}: '🩈'
BlackChessEquihopper\u{1fa49}: '🩉'
NeutralChessEquihopper\u{1fa4a}: '🩊'
WhiteChessEquihopperRotatedNinetyDegrees\u{1fa4b}: '🩋'
BlackChessEquihopperRotatedNinetyDegrees\u{1fa4c}: '🩌'
NeutralChessEquihopperRotatedNinetyDegrees\u{1fa4d}: '🩍'
WhiteChessKnightDashQueen\u{1fa4e}: '🩎'
WhiteChessKnightDashRook\u{1fa4f}: '🩏'
WhiteChessKnightDashBishop\u{1fa50}: '🩐'
BlackChessKnightDashQueen\u{1fa51}: '🩑'
BlackChessKnightDashRook\u{1fa52}: '🩒'
BlackChessKnightDashBishop\u{1fa53}: '🩓'
XiangqiRedGeneral\u{1fa60}: '🩠'
XiangqiRedMandarin\u{1fa61}: '🩡'
XiangqiRedElephant\u{1fa62}: '🩢'
XiangqiRedHorse\u{1fa63}: '🩣'
XiangqiRedChariot\u{1fa64}: '🩤'
XiangqiRedCannon\u{1fa65}: '🩥'
XiangqiRedSoldier\u{1fa66}: '🩦'
XiangqiBlackGeneral\u{1fa67}: '🩧'
XiangqiBlackMandarin\u{1fa68}: '🩨'
XiangqiBlackElephant\u{1fa69}: '🩩'
XiangqiBlackHorse\u{1fa6a}: '🩪'
XiangqiBlackChariot\u{1fa6b}: '🩫'
XiangqiBlackCannon\u{1fa6c}: '🩬'
XiangqiBlackSoldier\u{1fa6d}: '🩭'
Methods
impl ChessSymbols[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case